( cd usr/lib64 ; rm -rf libstdc++.so.5 )
( cd usr/lib64 ; ln -sf libstdc++.so.5.0.7 libstdc++.so.5 )
( cd usr/lib64 ; rm -rf libstdc++.so.6 )
( cd usr/lib64 ; ln -sf libstdc++.so.6.0.9 libstdc++.so.6 )
